%Run this file when ready to initialize the total system.

clear;
%Earth data:
g           =9.81;          %Earth gravity  
P_atm       = 101325;       %Atmospheric pressure

%Ocean data:
ro_sw       = 1025;         %Density of seawater [kg/m^3]
H_sea       = 200;          %Ocean depth [m]
my_sw       = 0.0012;       %Viscosity of seawater [kg/]
%my_sw       = 0.00001818;  %Viscosity of air [kg/]
%ro_sw       = 1.204;       %Density of air [kg/m^3]

%Plough data
m_p         = 52000;        %Plough's mass submerged [kg]
alpha       = 30*pi/180;    %Ploughshare angle [rad]
h_p         = 1.5;          %Ploughshare height [m]
w_p         = 0.5;          %Ploughshare width [m]

%Seabed data:
k           = 0.00008001;   %Permeability of porewater in the seabed sediment [m/s]
epsilon_v   = 0.05;         %Volumetric strain
ro_ss_init  = 1087;         %Density of the seabed sediment [kg/m^3]
fi          = 38*pi/180;    %Friction angle of the seabed sediment [rad]
sig_crit    = 98429.741;    %Critical confining stress [kg/m^2]
my          = 0;            %Seabed sediment on blade friction
Nfi         = (tan((pi+(2*fi))/4))^2;
psi         = (4.5*(1+Nfi))/(((2*Nfi)+1)*(Nfi+2));
F0          = (ro_ss_init*w_p*h_p^2/2)*Nfi;
Nx          = ((sin(alpha)+cos(alpha)*my)/Nfi)*...
              ((1/tan(alpha))+tan((fi/2)+(alpha/2)))*...
              (((Nfi*sin(fi)/3)*(h_p/w_p))+cos((fi/2)-(alpha/2)))/...
              (cos((fi/2)+(alpha/2))-my*sin((fi/2)+(alpha/2)));
b_p         = F0*Nx;
A           = h_p*ro_ss_init/(psi*sig_crit);
B           = 4*k*ro_ss_init/(ro_sw*epsilon_v);

%Surface vessel data:
m_v         = 5.3122e6;     %Vessels mass and added mass [kg] 
d_v         = 5.0242e4;     %Vessels skin friction damping

%Towline data:
deltaLmaxPros = 0.5/100;
E           = 1960/(0.001*0.001); %Young's Modulus for the towline [N/m^2] 300mton
mt          = 13.9;               %Towlines mass pr. meter [kg/m] 
d           = 0.057;              %Towline diameter [m]
A_e         = 1480/(1000*1000);   %Towlines cross section [m^2]
ro_t        = mt/A_e;             %Towlines density [kg/m^3]
ne          = 25;                 %Numbert of towline elements

%Initializing the towline
T0          = b_p;          %Catenary Horizontal static tension [kg]
a           = T0/mt;        %Coeffisient for the catenary equation [m]
Max_x       = 1000;         %Integration area for the catenary equation
zc(1,1)     = H_sea;        %Catenary curves bottom z-position
xc(1,1)     = 0;            %Catenary curves bottom x-position
bool = 0;
for t= 2:1:Max_x    
    zc(t,1)= (a*(-exp(t/a)-exp(-t/a))/2)+a+H_sea; %catenary z along curve
    xc(t,1)= t;                                   %catenary x along curve
    if zc(t,1) <= 0 && bool == 0
        xfinal = t;
        bool = 1;
    end
end

%The angle of the 1st. towline element (vessel)
teta_cat    = atan((zc(xfinal-1,1)-zc(xfinal-2,1))/(xc(xfinal-1,1)-xc(xfinal-2,1)));
deg         = teta_cat*180/pi;
%Tangential tension in the 1st. element
T           = abs(T0/cos(teta_cat));

%xfinal= a*acosh((H_sea/a)+1);

%Length of the unstretced towline
LL          = a*sinh(xfinal/a)/((T*9.81/(E*A_e))+1);
%Stretched length
delta_L     = a*sinh(xfinal/a)-LL;
%Experimental compensation
delta_L     = 2*delta_L-4.6954;
%Length of the catenary curv
s           = a*sinh(xfinal/a);
%New length of the unstretced towline
L           = a*sinh(xfinal/a)-delta_L; 
%Length of each towline element
Le          = L/ne;         %Length of each unstretched towline element
%
teta        = asin(H_sea/L);%Angle between the horizontal plane and the line between the plough and the surface vessel
Lex         = Le*cos(teta); %Length of each unstretched towline element decomposed into the horizontal plane
Lez         = Le*sin(teta); %Length of each unstretched towline element decomposed into the vertical plane
for i= 0:1:ne
   x(i+1,1) = (i)*Lex;      %Towlines x-position along the straight line between the ploug and the surface vessel
   z(i+1,1) = (ne-i)*Lez;   %Towlines z-position along the straight line between the ploug and the surface vessel
end

%Vessel's Position in the (x,z) plane
x(ne+1,1)   = xfinal;
z(ne+1,1)   = 0;

%Computation of the triangular configuration for the 1st. towline node's initial position 
dl          = sqrt((x(ne+1,1)-x(ne+1-2,1))^2+(z(ne+1,1)-z(ne+1-2,1))^2)/2;
dy          = sqrt(Le^2-dl^2);
fi1         = acos((x(ne+1,1)-x(ne+1-2,1))/(dl*2));
fi2         = acos(dl/Le);
fi3         = pi-(fi1+fi2);
x(ne,1)     = x(ne+1,1)+Le*cos(fi3);
z(ne,1)     = Le*sin(fi3);

%Buoyancy force of each towline element:
B_e         = ro_sw*A_e*Le*g;

%Mass of each towline element:
m_e         = mt*Le; 

%Spring Constant:
K           = E*A_e/Le; 

%Internal damping coefficient
Cv          = sqrt(2*K/m_e)*m_e;

%Atmospheric pressure as sea height: H_atm [m]
H_atm       = P_atm/(g*ro_sw);

%init = 0 when in initialization mode. When running Init2.m this constant
%will be set to 1 for simulation of the total system 
init        = 0;
%Initializing constant for the 1st. order horizontal towline force filter
%in the DP-controller.
T1x         = 0;

%plotting the catenary and the 1st initial towline curve
plot(x,z,xc,zc),xlabel('x [m]'),ylabel('z [m]'),grid;
